# Generated by Django 2.0.13 on 2020-03-04 13:01

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='BarCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('next_code', models.IntegerField(blank=True, default=1, null=True, verbose_name='Next bar code')),
            ],
            options={
                'verbose_name': 'Bar code',
                'verbose_name_plural': 'Bar codes',
            },
        ),
    ]
